@@ -340,7 +340,7 @@ class TextComp(Component):
         self.font_path = cache_file(self.font_url)
         rs = TextClip(txt= self.text, font = self.font_path.replace("\\","/"), fontsize=self.font_size, color=self.color,
                         bg_color = self.bg_color, size=(int(self.position['width']), int(self.position['height'])+10),
-                        stroke_color = self.stroke_color, stroke_width=self.stroke_width, method='caption', align='center')
+                        stroke_color = self.stroke_color, stroke_width=self.stroke_width)
         return rs
 
 
