@@ -46,7 +46,10 @@ def create_compilation_songs(data, job_id, mf_server):
                     arr_song_info = requests.get("http://source.automusic.win/config/f-retrieve/"+arr_tmp[2] +
                                                  f"?jobid={job_id}&mfs={urllib.parse.quote_plus(mf_server)}", timeout= 600).json()
                     for song_info in arr_song_info:
-                        arr_songs.append({"uri":"direct:track:"+song_info['url_128'], "repeat":1})
+                        try:
+                            arr_songs.append({"uri":"direct:track:"+song_info['url_128'], "repeat":1})
+                        except:
+                            pass
 
                 #after download song, re-check song
                 try:
@@ -72,6 +75,8 @@ def create_compilation_songs(data, job_id, mf_server):
                 file_merg.write("file '%s'\n" % song['local'])
                 cnt_song+=1
             except:
+                import traceback
+                traceback.print_exc()
                 pass
         file_merg.close()
         if cnt_song>1:
